@@ -50,7 +50,7 @@ static void dump_services( int fd )
 void dump_internal_state(void)
 {
    int dump_fd ;
-   char *dump_file = DUMP_FILE ;
+   const char *dump_file = DUMP_FILE ;
    time_t current_time ;
    int fd ;
    unsigned u ;
@@ -72,7 +72,9 @@ void dump_internal_state(void)
 	* If the above function failed, Sprint will most likely
 	* fail, too. Output a message for troubleshooting and quit.
 	*/
-       msg( LOG_ERR, func, "failed setting up sio buffering: %m" ) ;
+       msg( LOG_ERR, func, 
+            "failed setting up sio buffering: %m fd:%d", dump_fd ) ;
+       Sclose(dump_fd);
        return;
    }
 
@@ -217,7 +219,8 @@ static void consistency_check( enum check_type type )
             continue ;
          }
       }
-      else
+      /* TCPMUX client programs are always stopped until they run. */
+      else if ( ! SVC_IS_MUXCLIENT( sp ) )
       {
          msg( LOG_ERR, func, "service %s not started", SVC_ID( sp ) ) ;
          error_count++ ;
