@@ -9,7 +9,7 @@
 #define SCONF_H
 
 /*
- * $Id: sconf.h,v 1.3 2003/03/14 00:39:51 steveg Exp $
+ * $Id: sconf.h,v 1.7 2003/06/25 19:43:56 bbraun Exp $
  */
 #include "config.h"
 #ifdef HAVE_STDINT_H
@@ -72,6 +72,7 @@
 #define LO_EXIT      5
 #define LO_PID       6
 #define LO_USERID    7
+#define LO_TRAFFIC   8
 
 struct rpc_data
 {
@@ -105,7 +106,7 @@ struct service_config
    char                *sc_id ;                /* e.g. "echo-stream"          */
    uint16_t             sc_port ;              /* in host byte order          */
    int                  sc_socket_type ;       /* e.g. SOCK_DGRAM             */
-   struct name_value    sc_protocol ;          /* e.g. "TCP", IPPROTO_TCP     */
+   struct protocol_name_value sc_protocol ;    /* e.g. "TCP", IPPROTO_TCP     */
    boolean_e            sc_wait ;
    uid_t                sc_uid ;
    gid_t                sc_user_gid ;          /* gid corresponding to uid    */
@@ -154,6 +155,8 @@ struct service_config
                                                   X: X minutes          */
 #ifdef HAVE_DNSREGISTRATION
    dns_service_discovery_ref sc_mdnscon;
+   char                *sc_mdns_name;
+   boolean_e            sc_mdns;
 #endif
 } ;
 
