@@ -167,7 +167,7 @@ static status_e set_fd_modes( struct service *sp )
 static status_e activate_rpc( struct service *sp )
 {
    union xsockaddr        tsin;
-   int                    sin_len = sizeof(tsin);
+   unsigned int           sin_len = sizeof(tsin);
    unsigned long          vers ;
    struct service_config *scp = SVC_CONF( sp ) ;
    struct rpc_data       *rdp = SC_RPCDATA( scp ) ;
@@ -252,8 +252,11 @@ static status_e activate_normal( struct service *sp )
    uint16_t                service_port   = SC_PORT( scp ) ;
    char                   *sid            = SC_ID( scp ) ;
    const char             *func           = "activate_normal" ;
-   int                     sin_len        = sizeof(tsin);
+   unsigned int            sin_len        = sizeof(tsin);
    int                     on             = 1;
+#ifdef IPV6_V6ONLY
+   int                     v6on           = 0;
+#endif
 
    if( scp->sc_bind_addr != NULL )
       memcpy(&tsin, scp->sc_bind_addr, sin_len);
@@ -270,6 +273,19 @@ static status_e activate_normal( struct service *sp )
       sin_len = sizeof(struct sockaddr_in6);
    }
 
+#ifdef IPV6_V6ONLY
+   if( SC_IPV6(scp) ) {
+      if( SC_SPECIFIED(scp, A_V6ONLY) ) {
+         v6on = 1;
+      } else {
+         v6on = 0;
+      }
+      if( setsockopt(sd, IPPROTO_IPV6, IPV6_V6ONLY, (char *)&v6on, sizeof(v6on)) < 0 ) {
+         msg( LOG_ERR, func, "Setting IPV6_V6ONLY option failed (%m)" );
+      }
+   }
+#endif
+
    if ( setsockopt( sd, SOL_SOCKET, SO_REUSEADDR, 
                     (char *) &on, sizeof( on ) ) == -1 )
       msg( LOG_WARNING, func, 
@@ -335,7 +351,7 @@ status_e svc_activate( struct service *sp )
 
    if ( set_fd_modes( sp ) == FAILED )
    {
-      (void) close( sp->svc_fd ) ;
+      (void) Sclose( sp->svc_fd ) ;
       return( FAILED ) ;
    }
 
@@ -348,21 +364,24 @@ status_e svc_activate( struct service *sp )
    
    if ( status == FAILED )
    {
-      (void) close( sp->svc_fd ) ;
+      (void) Sclose( sp->svc_fd ) ;
       return( FAILED ) ;
    }
 
 #ifdef HAVE_DNSREGISTRATION
-   char *srvname;
-
-   if( asprintf(&srvname, "_%s._%s", scp->sc_name, scp->sc_protocol.name) < 0 ) 
+   if ( scp->sc_mdns == YES )
    {
-       deactivate( sp );
-       return( FAILED );
-   }
+      if( scp->sc_mdns_name )
+         free(scp->sc_mdns_name);
+      if( asprintf(&scp->sc_mdns_name, "_%s._%s", scp->sc_name, scp->sc_protocol.name) < 0 ) 
+      {
+          deactivate( sp );
+          return( FAILED );
+      }
 
-   scp->sc_mdnscon = DNSServiceRegistrationCreate("", srvname, "", 
+      scp->sc_mdnscon = DNSServiceRegistrationCreate("", scp->sc_mdns_name, "", 
 		   htons(scp->sc_port), "", mdns_callback, NULL);
+   }
 #endif
 
    if ( log_start( sp, &sp->svc_log ) == FAILED )
@@ -396,7 +415,7 @@ status_e svc_activate( struct service *sp )
 
 static void deactivate( const struct service *sp )
 {
-   (void) close( SVC_FD( sp ) ) ;
+   (void) Sclose( SVC_FD( sp ) ) ;
 
 #ifdef HAVE_DNSREGISTRATION
    if( SVC_CONF(sp)->sc_mdnscon )
@@ -842,7 +861,7 @@ void svc_postmortem( struct service *sp, struct server *serp )
 {
    struct service  *co_sp   = SERVER_CONNSERVICE( serp ) ;
    connection_s    *cp      = SERVER_CONNECTION( serp ) ;
-   char            *func    = "svc_postmortem" ;
+   const char      *func    = "svc_postmortem" ;
 
    SVC_DEC_RUNNING_SERVERS( sp ) ;
 
@@ -873,6 +892,8 @@ void svc_postmortem( struct service *sp, struct server *serp )
       cp = NULL;
    } else {
       if (cp) {
+         if ( SVC_SOCKET_TYPE( sp ) == SOCK_DGRAM )
+            drain( cp->co_descriptor ) ;
          free(cp);
 	 cp = NULL;
       }
@@ -880,3 +901,26 @@ void svc_postmortem( struct service *sp, struct server *serp )
    }
 }
 
+/*
+ * This function closes all service descriptors. This should be called 
+ * for all child processes that fork, but do not exec. This includes
+ * redirect, builtins, and tcpmux. The close on exec flag takes care of
+ * child processes that call exec. Without calling this, the listening 
+ * fd's are not closed and reconfig will fail.
+ */
+void close_all_svc_descriptors(void)
+{
+   psi_h                     iter ;
+   struct service            *osp ;
+
+   /* Have to close all other descriptors here */
+   iter = psi_create( SERVICES( ps ) ) ;
+   if ( iter == NULL )
+        out_of_memory( "close_all_svc_descriptors" ) ;
+
+   for ( osp = SP( psi_start( iter ) ) ; osp ; osp = SP( psi_next( iter ) ) )
+        (void) Sclose( SVC_FD( osp ) ) ;
+  
+   psi_destroy( iter ) ;
+}
+
