@@ -218,11 +218,12 @@ static status_e handle_signal( int sig )
 #ifdef NO_POSIX_SIGS
          sig_handler = general_handler ;
 #else
-         sig_handler = (sigfunc *)mem_fault_handler ;
+         sa.sa_sigaction= mem_fault_handler ;
+         sig_handler = NULL ;
          sa.sa_flags = SA_SIGINFO ;
 #endif
+         break;
 #endif
-
       case SIGTRAP:
          if ( debug.on )
             return( OK ) ;
@@ -232,7 +233,8 @@ static status_e handle_signal( int sig )
    }
 
    sigemptyset( &sa.sa_mask ) ;
-   sa.sa_handler = sig_handler ;
+   if ( sig_handler )
+      sa.sa_handler = sig_handler ;
    return( ( sigaction( sig, &sa, SIGACTION_NULL ) == -1 ) ? FAILED : OK ) ;
 }
 
@@ -354,35 +356,44 @@ static void mem_fault_handler( int sig, siginfo_t * siginfo, void *context )
       switch (sig) {
          case SIGSEGV:
             switch (siginfo->si_code) {
+#ifdef SEGV_MAPERR
                case SEGV_MAPERR:
                   msg(LOG_CRIT, func, "address is not mapped for object");
                   break;
+#endif
+#ifdef SEGV_ACCERR
                case SEGV_ACCERR:
                   msg(LOG_CRIT, func, 
 			     "invalid permissions for mapped object");
                   break;
+#endif
                default:
-                  msg(LOG_CRIT, func, "unknown fault code");
+                  msg(LOG_CRIT, func, "unknown fault code %d",siginfo->si_code);
             }
             break;
 
          case SIGBUS:
             switch(siginfo->si_code) {
+#ifdef BUS_ADRALN
                case BUS_ADRALN:
                   msg(LOG_CRIT, func, "invalid address alignment");
                   break;
+#endif
+#ifdef BUS_ADRERR
                case BUS_ADRERR:
                   msg(LOG_CRIT, func, "nonexistent physical address");
                   break;
+#endif
+#ifdef BUS_OBJERR
                case BUS_OBJERR:
                   msg(LOG_CRIT, func, "object-specific hardware error");
                   break;
+#endif
                default:
-                  msg(LOG_CRIT, func, "unknown fault code");
+                  msg(LOG_CRIT, func, "unknown fault code %d",siginfo->si_code);
             }
             break;
       }
-           	   
    }
 
    /* Now call old function for handling */
